@@ -1,3 +1,3 @@
 #!/bin/sh
 export SDL_VIDEO_X11_WMCLASS=Maelstrom
-/usr/games/Maelstrom/Maelstrom
+/opt/maelstrom/bin/Maelstrom
