@@ -154,7 +154,11 @@ void PrintUsage(void)
 	error("or\n");
 	error("Usage: %s <options>\n\n", progname);
 	error("Where <options> can be any of:\n\n"
+#ifdef MAEMO
+"	-nofullscreen		# Don't run Maelstrom in full-screen mode\n"
+#else
 "	-fullscreen		# Run Maelstrom in full-screen mode\n"
+#endif
 "	-gamma [0-8]		# Set the gamma correction\n"
 "	-volume [0-8]		# Set the sound volume\n"
 "	-netscores		# Use the world-wide network score server\n"
@@ -309,9 +313,11 @@ int main(int argc, char *argv[])
 			switch (event.key.keysym.sym) {
 
 				/* -- Toggle fullscreen */
+#ifdef MAEMO
 				case SDLK_F6:
 					screen->ToggleFullScreen();
 					break;
+#endif
 				case SDLK_RETURN:
 					if ( event.key.keysym.mod & KMOD_ALT )
 						screen->ToggleFullScreen();
@@ -346,6 +352,9 @@ int main(int argc, char *argv[])
 					break;
 
 				/* -- Let them leave */
+#ifdef MAEMO
+				case SDLK_ESCAPE:
+#endif
 				case SDLK_q:
 					RunQuitGame();
 					break;
